# Authors

## Coding Contributors
- [Ethan Blaser](https://github.com/blaserethan)
- [John Engelke](https://github.com/jpl-jengelke)
- [Tamim Fatahi](https://github.com/tamimfatahi)
- [Michael Fitzgerald](https://github.com/mfitzasp)
- [Sujay Nair](https://github.com/sujaynair03)
- [Kyle Pearson](https://github.com/pearsonkyle)
- Gael Roudier
- [Marlee Smith](https://github.com/mjs2369)
- [Aaron Tran](https://github.com/FuwaFuwaKamiSama)
- Jon Varghese
- [Rob Zellem](https://github.com/rzellem)

## Translators
- [Leon Bewersdorff](https://github.com/LeonBew) - German
- [Kaio Duarte Costa](https://github.com/kaiodcosta) - Português do Brasil
